@@ -25,14 +25,27 @@ class TokenClassificationBenchmark(AbstractBenchmark):
                     start and ending index of word-span
     """
 
-    def __init__(self):
+    def __init__(self, pet_dataset=None):
         super(TokenClassificationBenchmark, self).__init__()
         #
         # # store strategy
         # self.change_matching_strategy(matching_strategy)
 
         #  load PET data
-        self.PETdataset = TokenClassification()
+        if pet_dataset:
+            assert isinstance(pet_dataset, TokenClassification)
+            self.PETdataset = pet_dataset
+        else:
+            self.PETdataset = TokenClassification()
+    #
+    # def __init__(self):
+    #     super(TokenClassificationBenchmark, self).__init__()
+    #     #
+    #     # # store strategy
+    #     # self.change_matching_strategy(matching_strategy)
+    #
+    #     #  load PET data
+    #     self.PETdataset = TokenClassification()
         self.goldstandard = self.GetGoldStandard()
         #  load goldstandard data
         # self.goldstandard = self.GetGoldStandard(tc)
@@ -63,7 +76,7 @@ class TokenClassificationBenchmark(AbstractBenchmark):
 
             for items_in_sentence in items_collection:
                 for item_in_sentence in items_in_sentence:
-                    flatten_item.extend(items_in_sentence)
+                    flatten_item.append(item_in_sentence)
 
             return flatten_item
 
